@@ -2,12 +2,16 @@ from .networking import (
     FLSMCalculator,
     VLSMCalculator,
     SubnetRow,
+    compress_ipv6,
+    expand_ipv6,
 )
 
 __all__ = [
     "FLSMCalculator",
     "SubnetRow",
-    "VLSMCalculator"
+    "VLSMCalculator",
+    "compress_ipv6",
+    "expand_ipv6"
 ]
 if False:
     from .networking import *  # Ayuda a linters
\ No newline at end of file
